bayespy.nodes.GaussianARD
=========================

.. currentmodule:: bayespy.nodes

.. autoclass:: GaussianARD

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~GaussianARD.__init__
      ~GaussianARD.add_plate_axis
      ~GaussianARD.broadcasting_multiplier
      ~GaussianARD.delete
      ~GaussianARD.get_gradient
      ~GaussianARD.get_mask
      ~GaussianARD.get_moments
      ~GaussianARD.get_parameters
      ~GaussianARD.get_riemannian_gradient
      ~GaussianARD.get_shape
      ~GaussianARD.has_plotter
      ~GaussianARD.initialize_from_mean_and_covariance
      ~GaussianARD.initialize_from_parameters
      ~GaussianARD.initialize_from_prior
      ~GaussianARD.initialize_from_random
      ~GaussianARD.initialize_from_value
      ~GaussianARD.load
      ~GaussianARD.logpdf
      ~GaussianARD.lower_bound_contribution
      ~GaussianARD.lowerbound
      ~GaussianARD.move_plates
      ~GaussianARD.observe
      ~GaussianARD.pdf
      ~GaussianARD.plot
      ~GaussianARD.random
      ~GaussianARD.rotate
      ~GaussianARD.rotate_plates
      ~GaussianARD.save
      ~GaussianARD.set_parameters
      ~GaussianARD.set_plotter
      ~GaussianARD.show
      ~GaussianARD.unobserve
      ~GaussianARD.update
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: generated/
   
      ~GaussianARD.dims
      ~GaussianARD.plates
      ~GaussianARD.plates_multiplier
   
   